@@ -180,6 +180,8 @@ var yyjson_8h =
     [ "yyjson_mut_val_write_file", "yyjson_8h.html#adf8b2d3c8b57e85d58108d58c68b0db5", null ],
     [ "yyjson_mut_val_write_fp", "yyjson_8h.html#acb80caf1bf1aecd6b68f38b84628c492", null ],
     [ "yyjson_mut_val_write", "yyjson_8h.html#a700da5ce5bf8bb9d3739cc73a0f51cdf", null ],
+    [ "yyjson_write_number", "yyjson_8h.html#a26250087651ed3282ef31a27a0673333", null ],
+    [ "yyjson_mut_write_number", "yyjson_8h.html#a9dec76e0a9d0c9e6039f2d15ec8b26fb", null ],
     [ "yyjson_doc_get_root", "yyjson_8h.html#aa33a13a85b840b3dbc1f8534db2bd8fc", null ],
     [ "yyjson_doc_get_read_size", "yyjson_8h.html#a33580e2537c25685fd1209951dcbc967", null ],
     [ "yyjson_doc_get_val_count", "yyjson_8h.html#a89cb55aebc946e462968a2bcace5ba5a", null ],
@@ -490,6 +492,12 @@ var yyjson_8h =
     [ "YYJSON_READ_ALLOW_INVALID_UNICODE", "yyjson_8h.html#abdbf139ee03d263c8a833fbef8cbf63c", null ],
     [ "YYJSON_READ_BIGNUM_AS_RAW", "yyjson_8h.html#a305e109d45b8e2b419b7266b839dffa0", null ],
     [ "YYJSON_READ_ALLOW_BOM", "yyjson_8h.html#af1d965029a44a6a65b9ef3f9a4ccbc09", null ],
+    [ "YYJSON_READ_ALLOW_EXT_NUMBER", "yyjson_8h.html#a17429af07c44e8d9b3f6083df78e2ab1", null ],
+    [ "YYJSON_READ_ALLOW_EXT_ESCAPE", "yyjson_8h.html#aa0ef136f329e2b6016ceddf508e2d996", null ],
+    [ "YYJSON_READ_ALLOW_EXT_WHITESPACE", "yyjson_8h.html#a63f7c53c14f9de30d222acaa287eb490", null ],
+    [ "YYJSON_READ_ALLOW_SINGLE_QUOTED_STR", "yyjson_8h.html#ade31e55bb9edddbaf2cd5c0c0ba03c64", null ],
+    [ "YYJSON_READ_ALLOW_UNQUOTED_KEY", "yyjson_8h.html#a38be7a9df2511df7d72b678379d7ca01", null ],
+    [ "YYJSON_READ_JSON5", "yyjson_8h.html#a8618ef9d06392f4267d853d8c0986319", null ],
     [ "YYJSON_READ_SUCCESS", "yyjson_8h.html#a5b8948d47748a81d6a4abf94949e0e88", null ],
     [ "YYJSON_READ_ERROR_INVALID_PARAMETER", "yyjson_8h.html#a841a5fd5b187b1ff40232e9d36a5a156", null ],
     [ "YYJSON_READ_ERROR_MEMORY_ALLOCATION", "yyjson_8h.html#a0b729e2b5afc21914a723897dda10c3f", null ],
